@@ -9,7 +9,11 @@ function(y,x,arp,method,scores=scores){
      if(method=="OLS"){
        fit <- lm(y2 ~ x2)
      } else if (method=="RANK") {
-       fit <- suppressWarnings(rfit(y2 ~ x2,scores=scores))
+	     p2 <- ncol(x) - 1
+	     n2 <- nrow(xy)
+	     x3 <- fullr(cbind(rep(1,n2),x2),1+arp+p2)
+#       fit <- suppressWarnings(rfit(y2 ~ x2,scores=scores))
+        fit <- rfit(y2 ~ x3[,-1],scores=scores)
      }
      return(fit)
 }
